@@ -1247,6 +1247,11 @@ Rcpp::NumericMatrix cubical_4dim(Rcpp::NumericVector& image, double threshold, i
     
     cp -> assemble_columns_to_reduce();
     cp -> compute_pairs_main(); // dim3
+    
+    // free pointers
+    delete jp;
+    delete cp;
+    
     break;		
   }
   case 1:
@@ -1262,10 +1267,18 @@ Rcpp::NumericMatrix cubical_4dim(Rcpp::NumericVector& image, double threshold, i
     cp -> assemble_columns_to_reduce();
     
     cp -> compute_pairs_main(); // dim3
+    
+    // free pointers
+    delete cp;
+    
     break;
   }
   }
   
+  // free pointers
+  delete dcg;
+  delete ctr;
+  
   Rcpp::NumericMatrix ans(writepairs.size(), 3);
   for (int i = 0; i < ans.nrow(); i++)
   {
